package App::RenameUtils;

our $DATE = '2019-07-23'; # DATE
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Utilities related to renaming files

__END__

=pod

=encoding UTF-8

=head1 NAME

App::RenameUtils - Utilities related to renaming files

=head1 VERSION

This document describes version 0.002 of App::RenameUtils (from Perl distribution App-RenameUtils), released on 2019-07-23.

=head1 DESCRIPTION

This distribution provides the following command-line utilities:

=over

=item * L<rename-swap>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-RenameUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-RenameUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-RenameUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<rename> from L<File::Rename>

L<perlmv> from L<App::perlmv>

L<renwd> from L<App::renwd>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
